@@ -1,4 +1,3 @@
-
 #' @importFrom ggplot2 aes
 #' @importFrom ggplot2 facet_wrap
 #' @importFrom ggplot2 geom_hline
@@ -55,52 +54,54 @@
 #' @examples
 #' alpha_discount(0.5)
 #'
-#' alpha_discount(0.5, discount_function="identity")
-#'
+#' alpha_discount(0.5, discount_function = "identity")
 #' @rdname alpha_discount
 #' @import methods
-#' @importFrom stats sd density is.empty.model median model.offset model.response pweibull quantile rbeta rgamma rnorm var vcov
+#' @importFrom stats sd density is.empty.model median model.offset
+#'   model.response pweibull quantile rbeta rgamma rnorm var vcov
 #' @aliases alpha_discount,ANY-method
 #' @export alpha_discount
 alpha_discount <- setClass("alpha_discount")
 
-setGeneric("alpha_discount",
-           function(p_hat             = NULL,
-                    discount_function = "weibull",
-                    alpha_max         = 1,
-                    weibull_scale     = 0.135,
-                    weibull_shape     = 3){
-             standardGeneric("alpha_discount")
-           })
-
-setMethod("alpha_discount",
-          signature(),
-          function(p_hat             = NULL,
-                   discount_function = "weibull",
-                   alpha_max         = 1,
-                   weibull_scale     = 0.135,
-                   weibull_shape     = 3){
-
-  # Check that discount_function is input correctly
-  all_functions <- c("weibull", "scaledweibull", "identity")
-  function_match <- match(discount_function, all_functions)
-  if(is.na(function_match)) {
-    stop("discount_function input incorrectly.")
+setGeneric(
+  "alpha_discount",
+  function(p_hat = NULL,
+           discount_function = "weibull",
+           alpha_max = 1,
+           weibull_scale = 0.135,
+           weibull_shape = 3) {
+    standardGeneric("alpha_discount")
   }
+)
 
-
-  # Compute alpha discount based on distribution
-  if(discount_function == "weibull"){
-    alpha_hat <- pweibull(p_hat, shape=weibull_shape,
-                               scale=weibull_scale)*alpha_max
-  } else if(discount_function == "scaledweibull"){
-    max_p <- pweibull(1, shape=weibull_shape, scale=weibull_scale)
-
-    alpha_hat <- pweibull(p_hat, shape=weibull_shape,
-                               scale=weibull_scale)*alpha_max/max_p
-  } else if(discount_function == "identity"){
-    alpha_hat <- p_hat
+setMethod(
+  "alpha_discount",
+  signature(),
+  function(p_hat = NULL,
+           discount_function = "weibull",
+           alpha_max = 1,
+           weibull_scale = 0.135,
+           weibull_shape = 3) {
+    
+    # Check that discount_function is input correctly
+    all_functions <- c("weibull", "scaledweibull", "identity")
+    function_match <- match(discount_function, all_functions)
+    if (is.na(function_match)) {
+      stop("discount_function input incorrectly.")
+    }
+    
+    
+    # Compute alpha discount based on distribution
+    if (discount_function == "weibull") {
+      alpha_hat <- pweibull(p_hat, shape = weibull_shape, scale = weibull_scale) * alpha_max
+    } else if (discount_function == "scaledweibull") {
+      max_p <- pweibull(1, shape = weibull_shape, scale = weibull_scale)
+      
+      alpha_hat <- pweibull(p_hat, shape = weibull_shape, scale = weibull_scale) * alpha_max / max_p
+    } else if (discount_function == "identity") {
+      alpha_hat <- p_hat
+    }
+    
+    return(alpha_hat)
   }
-
-  return(alpha_hat)
-})
+)
